@@ -1,5 +1,8 @@
-%% Copyright (C) 2016, 2018 Colin B. Macdonald
+%% Copyright (C) 2016, 2018-2019 Colin B. Macdonald
 %% Copyright (C) 2016 Abhinav Tripathi
+%% Copyright (C) 2021 Johannes Maria Frank
+%% Copyright (C) 2022 Chris Gorman
+%% Copyright (C) 2022 Alex Vong
 %%
 %% This file is part of OctSymPy.
 %%
@@ -51,6 +54,7 @@ function [A, info] = python_ipc_native(what, cmd, varargin)
   verbose = ~sympref('quiet');
 
   if (verbose && isempty(show_msg))
+    assert_pythonic_and_sympy ()
     fprintf ('Symbolic pkg v%s: ', sympref ('version'))
   end
 
@@ -59,6 +63,7 @@ function [A, info] = python_ipc_native(what, cmd, varargin)
   if isempty(have_headers)
     pyexec(strjoin({'import sys'
                     'import sympy'
+                    'import mpmath'
                     'import sympy as sp'
                     'from sympy import __version__ as spver'
                     'from sympy import *'
@@ -71,32 +76,43 @@ function [A, info] = python_ipc_native(what, cmd, varargin)
                     '# for hypergeometric'
                     'from sympy.functions.special.hyper import TupleArg'
                     '# for sets'
-                    'from sympy.sets.fancysets import *'
-                    'from sympy.sets.sets import *'
                     'from sympy.utilities.iterables import uniq'
+                    'try:'
+                    '    # quick fix for https://github.com/cbm755/octsympy/issues/1053'
+                    '    # TODO: investigate the sym ctor in this case, likely a better fix in there'
+                    '    from sympy.core.symbol import Str'
+                    'except ImportError:'
+                    '    pass'
                     'import copy'
                     'import struct'
                     'import codecs'
-                    'from distutils.version import LooseVersion'
+                    'try:'
+                    '    from packaging.version import Version'
+                    'except ImportError:'
+		    '    try:'
+		    '        from sympy.external.importtools import version_tuple as Version'
+		    '    except ImportError:'
+                    '        from distutils.version import LooseVersion'
+                    '        def Version(v):'
+                    '            return LooseVersion(v.replace(".dev", ""))'
                     'import itertools'
                     'import collections'
                     'from re import split'
-                    'def dictdiff(a, b):'
-                    '    """ keys from a that are not in b, used by evalpy() """'
-                    '    n = dict()'
-                    '    for k in a:'
-                    '        if not k in b:'
-                    '            n[k] = a[k]'
-                    '    return n'
-                    'def Version(v):'
-                    '    # short but not quite right: https://github.com/cbm755/octsympy/pull/320'
-                    '    return LooseVersion(v.replace(".dev", ""))'
+                    '# patch pretty printer, issue #952'
+                    'from sympy.printing.pretty.pretty import PrettyPrinter'
+                    '_mypp = PrettyPrinter'
+                    'def _my_rev_print(cls, f, **kwargs):'
+                    '    g = f.func(*reversed(f.args), evaluate=False)'
+                    '    return cls._print_Function(g, **kwargs)'
+                    '_mypp._print_LambertW = lambda cls, f: _my_rev_print(cls, f, func_name="lambertw")'
+                    '_mypp._print_sinc = lambda cls, f: cls._print_Function(f.func(f.args[0]/sp.pi, evaluate=False))'
+                    'del _mypp'
                   }, newl))
     have_headers = true;
   end
 
   if (verbose && isempty (show_msg))
-    fprintf ('Using experimental Python/C communications, SymPy v%s.\n', ...
+    fprintf ('using Pythonic interface, SymPy v%s.\n', ...
              char (py.sympy.__version__))
     show_msg = true;
   end
